adaptive library

Functions

isDisplayDesktop(BuildContext context) → bool
Returns a boolean value whether the window is considered medium or large size. Used to build adaptive and responsive layouts.
isDisplaySmallDesktop(BuildContext context) → bool
Returns boolean value whether the window is considered medium size.